@@ -10,6 +10,8 @@ def plot(fc, mp_hdl, plot_type=2, plot_norm=0, plot_offset=0, legend=None,
     q = fc.ql_sta
     Iqp = fc.Iqp
 
+    if Iqp.ndim == 1:
+        Iqp = Iqp.reshape(1, -1) 
     sl = slice(0, min(q.size, Iqp.shape[1]))
     q = q[sl]
     Iqp = Iqp[:, sl]
