@@ -181,6 +181,8 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.plot_intt()
         elif tab_name == 'g2':
             self.plot_g2()
+        elif tab_name == 'twotime':
+            self.init_twotime()
 
     def init_tab(self):
         if self.data_state < 2:
@@ -396,14 +398,20 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             # 'current_file_index': max(0, self.list_view_target.currentRow()),
             'current_file_index': file_index,
             'plot_index': self.twotime_q_index.value(),
-            'cmap': self.cb_twotime_cmap.currentText()
+            'cmap': self.cb_twotime_cmap.currentText(),
+            'vmin': self.c2_min.value(),
+            'vmax': self.c2_max.value(),
         }
+
+        if kwargs['vmin'] < 0:
+            kwargs['vmin'] = None
+        if kwargs['vmax'] < 0:
+            kwargs['vmax'] = None
+
         if kwargs['plot_index'] == 0:
             self.statusbar.showMessage("No twotime data for plot_indx = 0.")
             return
-        ret = self.vk.plot_twotime(self.mp_2t.hdl, **kwargs)
-        # if ret is not None:
-        #     self.vk.get_twotime_qindex(ret[1], ret[0], self.mp_2t_map.hdl)
+        self.vk.plot_twotime(self.mp_2t.hdl, self.mp_2t_map.hdl, **kwargs)
 
     def edit_label(self):
         if not self.check_status():
@@ -763,8 +771,6 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.vk.set_path(f)
             self.vk.clear()
 
-        print(self.vk.cwd)
-
         self.reload_source()
 
         self.avg_job_table.setModel(self.vk.avg_worker)
@@ -1032,7 +1038,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
 
     def clear_target_selection(self):
         self.list_view_target.clearSelection()
-        self.list_view_source.repaint()
+        # self.list_view_target.repaint()
 
     def update_g2_fitting_function(self):
         idx = self.g2_fitting_function.currentIndex()
