@@ -9,6 +9,7 @@ from .helper.fitting import fit_with_fixed
 import pyqtgraph as pg
 from .fileIO.hdf_to_str import get_hdf_info
 from pyqtgraph.Qt import QtGui
+import traceback
 
 
 def single_exp_all(x, a, b, c, d):
@@ -55,6 +56,32 @@ def power_law(x, a, b):
     return a * x ** b
 
 
+def reshape_static_analysis(info):
+    shape = (int(info['snoq']), int(info['snophi']))
+    size = shape[0] * shape[1]
+    # results from gpu code has a dimension problem; to be fixed later
+    if not isinstance(info['sphilist'], float): 
+        nan_idx = np.isnan(info['sphilist'])
+        Iqp = info['Iqp']
+        # if using the original data doesn't contain nan
+        if nan_idx.shape[0] != Iqp.shape[1]:
+            x = np.zeros((Iqp.shape[0], size), dtype=np.float32)
+            for n in range(Iqp.shape[0]):
+                x[n, ~nan_idx] = Iqp[n]
+                x[n, nan_idx] = np.nan
+            Iqp = x
+
+        Iqp = Iqp.reshape(Iqp.shape[0], *shape)
+        # average the phi dimension
+        Iqp = np.nanmean(Iqp, axis=2)
+        q = info['ql_sta'].reshape(*shape).T
+        q = np.nanmean(q, axis=0)
+        return Iqp, q
+
+    else:
+        return None, None
+
+
 class XpcsFile(object):
     """
     XpcsFile is a class that wraps an Xpcs analysis hdf file;
@@ -69,7 +96,7 @@ class XpcsFile(object):
         self.label = create_id(fname)
 
         self.type = get_type(self.full_path)
-        self.keys, attr = self.load(fields)
+        self.keys, attr = self._load(fields)
         self.__dict__.update(attr)
 
         self.hdf_info = None
@@ -94,9 +121,6 @@ class XpcsFile(object):
         ans = '\n'.join([ans, self.__str__()])
         return ans
 
-    def __add__(self, other):
-        pass
-
     def get_hdf_info(self, fstr=None):
         """
         get a text representation of the xpcs file; the entries are organized
@@ -104,7 +128,7 @@ class XpcsFile(object):
         :param fstr: list of filter strings, ['string_1', 'string_2', ...]
         :return: a list strings
         """
-        # only call it once because it may take long time to generate the str
+        # cache the data because it may take long time to generate the str
         if self.hdf_info is None:
             self.hdf_info = get_hdf_info(self.cwd, self.fname)
 
@@ -130,13 +154,13 @@ class XpcsFile(object):
 
         return msg
 
-    def load(self, extra_fields=None):
+    def _load(self, extra_fields=None):
         # default common fields for both twotime and multitau analysis;
         fields = ['saxs_2d', "saxs_1d", 'Iqp', 'ql_sta', 'Int_t', 't0', 't1',
                   'ql_dyn', 'type', 'dqmap', 'ccd_x0', 'ccd_y0', 'det_dist',
                   'pix_dim_x', 'pix_dim_y', 'X_energy', 'xdim', 'ydim',
                   'avg_frames', 'stride_frames', 'snoq', 'snophi', 'dnoq',
-                  'dnophi']
+                  'dnophi', 'sphilist']
 
         # extra fields for twotime analysis
         if self.type == 'Twotime':
@@ -171,12 +195,18 @@ class XpcsFile(object):
 
         for key in ['snoq', 'snophi', 'dnoq', 'dnophi']:
             ret[key] = int(ret[key])
-        
+
         self.reshape_phi_analysis(ret)
 
         return ret.keys(), ret
-    
+
     def reshape_phi_analysis(self, info):
+        """
+        the saxs1d and stability data are compressed. the values of the empty 
+        static bins are not saved. this function reshapes the array and fills
+        the empty bins with nan. nanmean is performed to get the correct
+        results;
+        """
         new_shape = (info['snoq'], info['snophi'])
         fields = ['sphilist', 'sqspan', 'sphispan']
         ret = get(self.full_path, fields, mode='alias', ret_type='list')
@@ -188,19 +218,28 @@ class XpcsFile(object):
             sq = (sqspan[1:] + sqspan[:-1]) / 2.0
 
             nan_idx = np.isnan(sphilist)
-            saxs1d = np.zeros_like(sphilist)
-            saxs1d[~nan_idx] = info['saxs_1d']
+            if info['saxs_1d'].shape == sphilist.shape:
+                saxs1d = info['saxs_1d']
+            else:
+                saxs1d = np.zeros_like(sphilist)
+                saxs1d[~nan_idx] = info['saxs_1d']
             saxs1d[nan_idx] = np.nan
             saxs1d = saxs1d.reshape(*new_shape).T
-            #sphilist = sphilist.reshape(*new_shape).T
 
             avg = np.nanmean(saxs1d, axis=0)
             saxs1d = np.vstack([avg, saxs1d])
 
-            labels = [self.label + '_%d' % (n + 1) for n in range(info['snophi'])]
+            labels = [self.label + '_%d' % (n + 1)
+                      for n in range(info['snophi'])]
             labels = [self.label] + labels
 
-        else:        
+            # reshape Iqp and ql_sta
+            Iqp, q = reshape_static_analysis(info)
+            if Iqp is not None:
+                info['Iqp'] = Iqp
+                info['ql_sta'] = q 
+
+        else:
             sq = info['ql_sta']
             sq = sq[~np.isnan(sq)]
             saxs1d = info['saxs_1d'].reshape(1, -1)
@@ -226,7 +265,7 @@ class XpcsFile(object):
 
     def get_time_scale(self, group='xpcs'):
         # acquire time scale for twotime analysis
-        return self.t0 
+        return self.t0
 
     def get_twotime_maps(self, group='xpcs'):
         rpath = '/'.join([group, 'output_data'])
@@ -246,6 +285,8 @@ class XpcsFile(object):
         if self.type == 'Twotime':
             key_c2t = '/'.join([rpath, 'C2T_all'])
             idlist = get(self.full_path, [key_c2t], mode='raw')[key_c2t]
+            if idlist.size == 1:
+                idlist = idlist.reshape(1)
             idlist = [int(x[3:]) for x in idlist]
         else:
             idlist = [None]
@@ -265,10 +306,9 @@ class XpcsFile(object):
             return None
 
         c2 = c2_half + np.transpose(c2_half)
-        c2_translate = np.zeros(c2.shape)
-        c2_translate[:, 0] = c2[:, -1]
-        c2_translate[:, 1:] = c2[:, :-1]
-        c2 = np.where(c2 > 1.3, c2_translate, c2)
+        diag_idx = np.diag_indices(c2_half.shape[0], ndim=2)
+        c2[diag_idx] /= 2
+
         return c2
 
     def get_detector_extent(self):
@@ -299,9 +339,11 @@ class XpcsFile(object):
 
         if mode == 'saxs2d':
             try:
-                win = ImageViewDev()
+                # win = ImageViewDev()
+                win = pg.ImageView()
                 saxs2d.plot([self.saxs_2d], win, **kwargs)
             except Exception:
+                traceback.print_exc()
                 pass
         elif mode == 'saxs1d':
             win = MplCanvasBarV()
@@ -333,7 +375,7 @@ class XpcsFile(object):
         self.show('stability', **kwargs)
 
     def get_pg_tree(self):
-        _, data = self.load()
+        _, data = self._load()
         for key, val in data.items():
             if isinstance(val, np.ndarray):
                 if val.size > 4096:
@@ -476,7 +518,11 @@ class XpcsFile(object):
         for n in range(g2_err.shape[1]):
             data = g2_err[:, n]
             idx = data > threshold
-            avg = np.mean(data[idx])
+            # avoid averaging of empty slice
+            if np.sum(idx) > 0:
+                avg = np.mean(data[idx])
+            else:
+                avg = threshold
             g2_err_mod[np.logical_not(idx), n] = avg
 
         return g2_err_mod
